<?php
/**
 * The header for our theme
 *
 * @subpackage Dinero
 * @since 1.0
 * @version 0.1
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js no-svg">
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php if ( function_exists( 'wp_body_open' ) ) {
    wp_body_open();
} else {
    do_action( 'wp_body_open' );
}?>

<a class="screen-reader-text skip-link" href="#skip-content"><?php esc_html_e( 'Skip to content', 'dinero' ); ?></a>

<div id="header">
	<div class="container">
		<div class="topbar px-2">
			<div class="row mx-md-0">
				<div class="col-lg-5 col-md-6 align-self-center">
					<?php if (get_theme_mod('dinero_show_tagline',true)) {?>
		                <?php
	                  		$description = get_bloginfo( 'description', 'display' );
		                  	if ( $description || is_customize_preview() ) :
		                ?>
	                  	<p class="site-description text-center">
	                    	<?php echo esc_attr($description); ?>
	                  	</p>
	              		<?php endif; ?>
	          		<?php }?>
				</div>
				<div class="col-lg-3 col-md-6 text-lg-left text-center contacts py-2 align-self-center">
					<?php if(get_theme_mod('dinero_topheader_email')) {?>
						<a href="mailto:<?php echo esc_attr(get_theme_mod('dinero_topheader_email')); ?>"><p class="email mb-md-0 text-md-right text-center"><i class="far fa-envelope"></i><?php echo esc_html(get_theme_mod('dinero_topheader_email')); ?></p><span class="screen-reader-text"><?php echo esc_html(get_theme_mod('dinero_topheader_email')); ?></span></a>
					<?php }?>
				</div>
				<div class="col-lg-4 col-md-12 align-self-center">
					<div class="social-icons text-lg-right text-center">
						<?php if(get_theme_mod('dinero_topheader_facebook_url')) {?>
							<a href="<?php echo esc_url(get_theme_mod('dinero_topheader_facebook_url')); ?>"><i class="fab fa-facebook-f"></i><span class="screen-reader-text"><?php echo esc_html('Facebook', 'dinero'); ?></span></a>
						<?php }?>
						<?php if(get_theme_mod('dinero_topheader_twitter_url')) {?>
							<a href="<?php echo esc_url(get_theme_mod('dinero_topheader_twitter_url')); ?>"><i class="fab fa-twitter"></i><span class="screen-reader-text"><?php echo esc_html('Twitter', 'dinero'); ?></span></a>
						<?php }?>
						<?php if(get_theme_mod('dinero_topheader_instagram_url')) {?>
							<a href="<?php echo esc_url(get_theme_mod('dinero_topheader_instagram_url')); ?>"><i class="fab fa-instagram"></i><span class="screen-reader-text"><?php echo esc_html('Instagram', 'dinero'); ?></span></a>
						<?php }?>
						<?php if(get_theme_mod('dinero_topheader_linkedin_url')) {?>
							<a href="<?php echo esc_url(get_theme_mod('dinero_topheader_linkedin_url')); ?>"><i class="fab fa-linkedin-in"></i><span class="screen-reader-text"><?php echo esc_html('Linkedin', 'dinero'); ?></span></a>
						<?php }?>
						<?php if(get_theme_mod('dinero_topheader_pinterest_url')) {?>
							<a href="<?php echo esc_url(get_theme_mod('dinero_topheader_pinterest_url')); ?>"><i class="fab fa-pinterest-p"></i><span class="screen-reader-text"><?php echo esc_html('Pinterest', 'dinero'); ?></span></a>
						<?php }?>
					</div>
				</div>
			</div>
		</div>
		<div class="bottom-header <?php if( get_theme_mod( 'dinero_show_sticky_header', false) != '') { ?> dinero-header <?php } ?>">
			<div class="menu-section">
				<div class="row mx-md-0">
					<div class="col-lg-3 col-md-4 col-9 align-self-center">
						<div class="logo">
							<?php if ( has_custom_logo() ) : ?>
			            		<?php the_custom_logo(); ?>
				            <?php endif; ?>
			             	<?php if (get_theme_mod('dinero_show_site_title',true)) {?>
			          			<?php $blog_info = get_bloginfo( 'name' ); ?>
				                <?php if ( ! empty( $blog_info ) ) : ?>
				                  	<?php if ( is_front_page() && is_home() ) : ?>
				                    	<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
				                  	<?php else : ?>
			                      		<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
			                  		<?php endif; ?>
				                <?php endif; ?>
				            <?php }?>
						</div>
					</div>
					<div class="col-lg-7 col-md-5 col-3 align-self-center">
						<div class="toggle-menu responsive-menu">
							<?php if(has_nav_menu('primary')){ ?>
				            	<button onclick="dinero_open()" role="tab" class="mobile-menu"><i class="fas fa-bars"></i><span class="screen-reader-text"><?php esc_html_e('Open Menu','dinero'); ?></span></button>
				            <?php }?>
				        </div>
						<div id="sidelong-menu" class="nav sidenav">
			                <nav id="primary-site-navigation" class="nav-menu" role="navigation" aria-label="<?php esc_attr_e( 'Top Menu', 'dinero' ); ?>">
			                  	<?php if(has_nav_menu('primary')){
				                    wp_nav_menu( array( 
										'theme_location' => 'primary',
										'container_class' => 'main-menu-navigation clearfix' ,
										'menu_class' => 'clearfix',
										'items_wrap' => '<ul id="%1$s" class="%2$s mobile_nav">%3$s</ul>',
										'fallback_cb' => 'wp_page_menu',
				                    ) ); 
			                  	} ?>
			                  	<a href="javascript:void(0)" class="closebtn responsive-menu" onclick="dinero_close()"><i class="fas fa-times"></i><span class="screen-reader-text"><?php esc_html_e('Close Menu','dinero'); ?></span></a>
			                </nav>
			            </div>
					</div>
					<?php if(get_theme_mod('dinero_topheader_phone_no')) {?>
						<div class="col-lg-2 col-md-3 phone">
							<i class="fas fa-phone-volume"></i>
							<a href="tel:<?php echo esc_attr(get_theme_mod('dinero_topheader_phone_no')); ?>"><?php echo esc_html(get_theme_mod('dinero_topheader_phone_no')); ?><span class="screen-reader-text"><?php echo esc_html(get_theme_mod('dinero_topheader_phone_no')); ?></span></a>
						</div>
					<?php }?>
				</div>
			</div>
		</div>
	</div>
</div>


<div id="inner-pages-header">
	<div class="header-overlay"></div>
    <div class='container'> 
    	<div class="header-content">
	      	<h1><?php single_post_title(); ?></h1>
	      	<?php if(is_singular() || get_theme_mod('dinero_show_breadcrumb',true) == true) {?>
				<div class="dinero-breadcrumb">
					<?php dinero_breadcrumb();?>
				</div>
			<?php } ?>
		</div>
    </div>
</div>