<?php
/**
 * Dinero: Customizer
 *
 * @subpackage Dinero
 * @since 1.0
 */

use WPTRT\Customize\Section\Dinero_Button;

add_action( 'customize_register', function( $manager ) {

	$manager->register_section_type( Dinero_Button::class );

	$manager->add_section(
		new Dinero_Button( $manager, 'dinero_pro', [
			'title'      => __( 'Dinero Pro', 'dinero' ),
			'priority'    => null,
			'button_text' => __( 'Go Pro', 'dinero' ),
			'button_url'  => esc_url( 'https://www.luzuk.com/product/multipurpose-corporate-wordpress-theme/', 'dinero')
		] )
	);

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

	$version = wp_get_theme()->get( 'Version' );

	wp_enqueue_script(
		'dinero-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
		[ 'customize-controls' ],
		$version,
		true
	);
	wp_localize_script(
		'dinero-customize-section-button',
		'dinero_customizer_params',
		array(
			'ajaxurl' =>	admin_url( 'admin-ajax.php' )
		)
	);

	wp_enqueue_style(
		'dinero-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
		[ 'customize-controls' ],
 		$version
	);

} );

function dinero_customize_register( $wp_customize ) {

	//add home page setting pannel
	$dinero_parent_panel = new Dinero_WP_Customize_Panel( $wp_customize, 'dinero_panel_id1', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'General Settings', 'dinero' ),
		'priority' => 10,
	));

	$wp_customize->add_panel( $dinero_parent_panel );

	$HeaderParentPanel = new Dinero_WP_Customize_Panel( $wp_customize, 'header_parent_panel', array(
		'title' => esc_html__( 'Header', 'dinero' ),
		'panel' => 'dinero_panel_id1',
		'priority' => 11,
	));

	$wp_customize->add_panel( $HeaderParentPanel );

	// All Settings
	$wp_customize->add_section( 'dinero_all_settings', array(
		'title' => esc_html__( 'All Settings', 'dinero' ),
		'panel' => 'header_parent_panel',
	));

	$wp_customize->add_setting('dinero_reset_header_all_settings',array(
      'sanitize_callback'	=> 'sanitize_text_field'
   ));
   $wp_customize->add_control(new Dinero_Reset_Custom_Control($wp_customize, 'dinero_reset_header_all_settings',array(
      'type' => 'reset_control',
      'label' => __('Reset All Settings', 'dinero'),
      'description' => 'dinero_reset_all_settings',
      'section' => 'dinero_all_settings'
   )));

	$wp_customize->add_setting('dinero_header_tabs', array(
	   'sanitize_callback' => 'wp_kses_post',
	));
	$wp_customize->add_control(new Dinero_Tab_Control($wp_customize, 'dinero_header_tabs', array(
	   'section' => 'dinero_all_settings',
	   'buttons' => array(
	      array(
	         'name' => esc_html__('General', 'dinero'),
            'fields' => array(
            	'dinero_show_sticky_header',
               'dinero_topheader_phone_no',
               'dinero_topheader_email',
               'dinero_topheader_facebook_url',
               'dinero_topheader_twitter_url',
               'dinero_topheader_instagram_url',
               'dinero_topheader_linkedin_url',
               'dinero_topheader_pinterest_url'
            ),
            'active' => true,
         ),
	      array(
            'name' => esc_html__('Style', 'dinero'),
            'fields' => array(
               'dinero_header_bg_color',
               'dinero_header_image',
               'dinero_site_title_color',
               'dinero_site_text_color',
               'dinero_mail_phone_icon_color',
               'dinero_mail_phone_text_color',
               'dinero_social_icon_color',
               'dinero_social_icon_hover_color'
            ),
         )
    	),
	)));

	$wp_customize->add_setting( 'dinero_show_sticky_header',array(
		'default' => false,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_sticky_header',array(
		'label' => __( 'Show Sticky Header','dinero' ),
		'section' => 'dinero_all_settings'
   )));

	$wp_customize->add_setting('dinero_topheader_phone_no',array(
    	'default' => '',
    	'sanitize_callback'	=> 'dinero_sanitize_phone_number'
	));
	$wp_customize->add_control('dinero_topheader_phone_no',array(
   	'type' => 'text',
   	'label' => __('Add Phone Number','dinero'),
   	'section' => 'dinero_all_settings',
	));

	$wp_customize->add_setting('dinero_topheader_email',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_email'
	));
	$wp_customize->add_control('dinero_topheader_email',array(
   	'type' => 'text',
   	'label' => __('Add Email Address','dinero'),
   	'section' => 'dinero_all_settings',
	));

	$wp_customize->add_setting('dinero_topheader_facebook_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('dinero_topheader_facebook_url',array(
   	'type' => 'url',
   	'label' => __('Add Facebook URL','dinero'),
   	'section' => 'dinero_all_settings',
	));

	$wp_customize->add_setting('dinero_topheader_twitter_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('dinero_topheader_twitter_url',array(
   	'type' => 'url',
   	'label' => __('Add Twitter URL','dinero'),
   	'section' => 'dinero_all_settings',
	));

	$wp_customize->add_setting('dinero_topheader_instagram_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('dinero_topheader_instagram_url',array(
   	'type' => 'url',
   	'label' => __('Add Instagram URL','dinero'),
   	'section' => 'dinero_all_settings',
	));

	$wp_customize->add_setting('dinero_topheader_linkedin_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('dinero_topheader_linkedin_url',array(
   	'type' => 'url',
   	'label' => __('Add Linkedin URL','dinero'),
   	'section' => 'dinero_all_settings',
	));

	$wp_customize->add_setting('dinero_topheader_pinterest_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('dinero_topheader_pinterest_url',array(
   	'type' => 'url',
   	'label' => __('Add Pinterest URL','dinero'),
   	'section' => 'dinero_all_settings',
	));

	$wp_customize->add_setting( 'dinero_header_bg_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_header_bg_color', array(
  		'label' => __('Header Background Color','dinero'),
	   'section' => 'dinero_all_settings',
  	)));

	$wp_customize->add_setting( 'dinero_header_image', array(
	   'default' => '',
	   'sanitize_callback' => 'esc_url_raw'
  	));
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'dinero_header_image', array(
  		'label' => __('Header Background Image','dinero'),
	   'section' => 'dinero_all_settings',
  	)));

	$wp_customize->add_setting( 'dinero_site_title_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_site_title_color', array(
  		'label' => __('Site Title Color','dinero'),
	   'section' => 'dinero_all_settings',
  	)));

	$wp_customize->add_setting( 'dinero_site_text_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_site_text_color', array(
  		'label' => __('Site Tagline Color','dinero'),
	   'section' => 'dinero_all_settings',
  	)));

	$wp_customize->add_setting( 'dinero_mail_phone_icon_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_mail_phone_icon_color', array(
  		'label' => __('Mail & Phone Icon Color','dinero'),
	   'section' => 'dinero_all_settings',
  	)));

	$wp_customize->add_setting( 'dinero_mail_phone_icon_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_mail_phone_icon_color', array(
  		'label' => __('Mail & Phone Icon Color','dinero'),
	   'section' => 'dinero_all_settings',
  	)));

	$wp_customize->add_setting( 'dinero_mail_phone_text_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_mail_phone_text_color', array(
  		'label' => __('Mail & Phone Text Color','dinero'),
	   'section' => 'dinero_all_settings',
  	)));

	$wp_customize->add_setting( 'dinero_social_icon_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_social_icon_color', array(
  		'label' => __('Social Icon Color','dinero'),
	   'section' => 'dinero_all_settings',
  	)));

	$wp_customize->add_setting( 'dinero_social_icon_hover_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_social_icon_hover_color', array(
  		'label' => __('Social Icon Hover Color','dinero'),
	   'section' => 'dinero_all_settings',
  	)));

  	// Logo Settings
	$wp_customize->add_section( 'title_tagline', array(
		'title' => esc_html__( 'Logo Settings', 'dinero' ),
		'panel' => 'header_parent_panel',
	));

	$wp_customize->add_setting('dinero_reset_header_logo_settings',array(
      'sanitize_callback'	=> 'sanitize_text_field'
   ));
   $wp_customize->add_control(new Dinero_Reset_Custom_Control($wp_customize, 'dinero_reset_header_logo_settings',array(
      'type' => 'reset_control',
	   'priority' => 1,
      'label' => __('Reset Logo Settings', 'dinero'),
      'description' => 'dinero_reset_logo_settings',
      'section' => 'title_tagline'
   )));

	$wp_customize->add_setting('dinero_logo_tabs', array(
	   'sanitize_callback' => 'wp_kses_post',
	));
	$wp_customize->add_control(new Dinero_Tab_Control($wp_customize, 'dinero_logo_tabs', array(
	   'section' => 'title_tagline',
	   'priority' => 1,
	   'buttons' => array(
	      array(
	         'name' => esc_html__('General', 'dinero'),
            'fields' => array(
            	'custom_logo',
            	'blogname',
            	'blogdescription',
            	'site_icon',
               'dinero_show_site_title',
               'dinero_show_tagline'
            ),
            'active' => true,
         ),
	      array(
            'name' => esc_html__('Layout', 'dinero'),
            'fields' => array(
               'dinero_logo_size',
               'dinero_logo_height',
               'dinero_logo_margin',
               'dinero_logo_top_margin',
               'dinero_logo_bottom_margin',
               'dinero_logo_left_margin',
               'dinero_logo_right_margin'
            ),
         )
    	),
	)));

	$wp_customize->add_setting( 'dinero_show_site_title',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_site_title',array(
		'label' => __( 'Site Title','dinero' ),
		'section' => 'title_tagline'
   )));

	$wp_customize->add_setting( 'dinero_show_tagline',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_tagline',array(
		'label' => __( 'Site Tagline','dinero' ),
		'section' => 'title_tagline'
   )));

	$wp_customize->add_setting('dinero_logo_size',array(
    	'default' => 100,
		'sanitize_callback' => 'dinero_sanitize_integer'
	));
	$wp_customize->add_control(new Dinero_Custom_Control( $wp_customize, 'dinero_logo_size',array(
   	'label' => __('Logo Width','dinero'),
   	'section' => 'title_tagline',
   	'input_attrs' => array(
			'min' => 0,
			'max' => 100,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting('dinero_logo_height',array(
    	'default' => '',
		'sanitize_callback' => 'dinero_sanitize_integer'
	));
	$wp_customize->add_control(new Dinero_Custom_Control( $wp_customize, 'dinero_logo_height',array(
   	'label' => __('Logo Height','dinero'),
   	'section' => 'title_tagline',
   	'input_attrs' => array(
			'min' => 0,
			'max' => 150,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting('dinero_logo_margin',array(
      'sanitize_callback'	=> 'esc_html'
   ));
   $wp_customize->add_control('dinero_logo_margin',array(
      'label' => __('Logo Margin','dinero'),
      'section' => 'title_tagline'
   ));

	$wp_customize->add_setting('dinero_logo_top_margin',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_logo_top_margin',array(
      'type' => 'number',
      'description' => __('Top','dinero'),
      'section' => 'title_tagline',
   ));

	$wp_customize->add_setting('dinero_logo_bottom_margin',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_logo_bottom_margin',array(
      'type' => 'number',
      'description' => __('Bottom','dinero'),
      'section' => 'title_tagline',
   ));

	$wp_customize->add_setting('dinero_logo_left_margin',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_logo_left_margin',array(
      'type' => 'number',
      'description' => __('Left','dinero'),
      'section' => 'title_tagline',
   ));

	$wp_customize->add_setting('dinero_logo_right_margin',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_logo_right_margin',array(
      'type' => 'number',
      'description' => __('Right','dinero'),
      'section' => 'title_tagline',
   ));

	//Menu options
	$wp_customize->add_section( 'dinero_menu_options' , array(
    	'title' => __( 'Menu Settings', 'dinero' ),
		'priority' => null,
		'panel' => 'header_parent_panel'
	) );

	$wp_customize->add_setting('dinero_reset_menu_settings',array(
      'sanitize_callback'	=> 'sanitize_text_field'
   ));
   $wp_customize->add_control(new Dinero_Reset_Custom_Control($wp_customize, 'dinero_reset_menu_settings',array(
      'type' => 'reset_control',
	   'priority' => 1,
      'label' => __('Reset Menu Settings', 'dinero'),
      'description' => 'dinero_reset_header_menu_settings',
      'section' => 'dinero_menu_options'
   )));

	$wp_customize->add_setting('dinero_menu_tabs', array(
	   'sanitize_callback' => 'wp_kses_post',
	));
	$wp_customize->add_control(new Dinero_Tab_Control($wp_customize, 'dinero_menu_tabs', array(
	   'section' => 'dinero_menu_options',
	   'priority' => 1,
	   'buttons' => array(
	      array(
	         'name' => esc_html__('General', 'dinero'),
            'fields' => array(
            	'dinero_submenu_animation',
            	'dinero_menu_case',
            	'dinero_menu_font_size',
            	'dinero_menu_font_weight'
            ),
            'active' => true,
         ),
	      array(
            'name' => esc_html__('Style', 'dinero'),
            'fields' => array(
            	'dinero_menu_color',
            	'dinero_menu_hover_color',
            	'dinero_active_menu_color',
            	'dinero_dropdown_menu_color',
            	'dinero_dropdown_bg_menu_color'
            ),
         )
    	),
	)));

	$wp_customize->add_setting('dinero_submenu_animation',array(
     'default' => 'Default',
     'sanitize_callback' => 'dinero_sanitize_choices'
	));
	$wp_customize->add_control('dinero_submenu_animation',array(
      'type' => 'select',
      'label' => __('Dropdown Menu Animation','dinero'),
      'section' => 'dinero_menu_options',
      'choices' => array(
         'Default' => __('Default','dinero'),
         'fadeInUp' => __('fadeInUp','dinero'),
         'zoomIn' => __('zoomIn','dinero'),
         'slideInUp' => __('slideInUp','dinero'),
         'flipInY' => __('flipInY','dinero')
      ),
	));

	$wp_customize->add_setting('dinero_menu_case',array(
     'default' => 'Default',
     'sanitize_callback' => 'dinero_sanitize_choices'
	));
	$wp_customize->add_control('dinero_menu_case',array(
      'type' => 'select',
      'label' => __('Menu Case','dinero'),
      'section' => 'dinero_menu_options',
      'choices' => array(
         'Default' => __('Default','dinero'),
         'Uppercase' => __('Uppercase','dinero'),
         'Capitalize' => __('Capitalize','dinero'),
         'Lowercase' => __('Lowercase','dinero')
      ),
	));

	$wp_customize->add_setting('dinero_menu_font_size',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_menu_font_size',array(
      'type' => 'number',
      'label' => __('Menu Font Size','dinero'),
      'section' => 'dinero_menu_options',
   ));

	$wp_customize->add_setting('dinero_menu_font_weight',array(
     'default' => '600',
     'sanitize_callback' => 'dinero_sanitize_choices'
	));
	$wp_customize->add_control('dinero_menu_font_weight',array(
      'type' => 'select',
      'label' => __('Font Weight','dinero'),
      'section' => 'dinero_menu_options',
      'choices' => array(
         '300' => __('300','dinero'),
         '400' => __('400','dinero'),
         '600' => __('600','dinero'),
         '700' => __('700','dinero'),
         '800' => __('800','dinero')
      ),
	));

	$wp_customize->add_setting( 'dinero_menu_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_menu_color', array(
  		'label' => 'Menu Color',
	   'section' => 'dinero_menu_options',
  	)));

	$wp_customize->add_setting( 'dinero_menu_hover_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_menu_hover_color', array(
  		'label' => 'Menu Hover Color',
	   'section' => 'dinero_menu_options',
  	)));

	$wp_customize->add_setting( 'dinero_active_menu_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_active_menu_color', array(
  		'label' => 'Active Menu Color',
	   'section' => 'dinero_menu_options',
  	)));

	$wp_customize->add_setting( 'dinero_dropdown_menu_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_dropdown_menu_color', array(
  		'label' => 'Dropdown Menu Color',
	   'section' => 'dinero_menu_options',
  	)));

	$wp_customize->add_setting( 'dinero_dropdown_bg_menu_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_dropdown_bg_menu_color', array(
  		'label' => 'Dropdown Menu Background Color',
	   'section' => 'dinero_menu_options',
  	)));

   $PagesParentPanel = new Dinero_WP_Customize_Panel( $wp_customize, 'dinero_pages_parent_panel', array(
		'title' => esc_html__( 'Pages', 'dinero' ),
		'panel' => 'dinero_panel_id1',
		'priority' => 11,
	));

	$wp_customize->add_panel( $PagesParentPanel );

	//Inner Pages
   $wp_customize->add_section( 'dinero_inner_pages', array(
    	'title'  => __( 'Inner Pages', 'dinero' ),
		'panel' => 'dinero_pages_parent_panel'
	) );

	$wp_customize->add_setting('dinero_inner_page_tabs', array(
	   'sanitize_callback' => 'wp_kses_post',
	));
	$wp_customize->add_control(new Dinero_Tab_Control($wp_customize, 'dinero_inner_page_tabs', array(
	   'section' => 'dinero_inner_pages',
	   'priority' => 1,
	   'buttons' => array(
	      array(
	         'name' => esc_html__('General', 'dinero'),
            'fields' => array(
            	'dinero_inner_pages_padding',
            	'dinero_page_top_padding',
            	'dinero_page_bottom_padding'
            ),
            'active' => true,
         ),
	      array(
            'name' => esc_html__('Layout', 'dinero'),
            'fields' => array(
            	'dinero_page_sidebar'
            ),
         ),
	      array(
            'name' => esc_html__('Style', 'dinero'),
            'fields' => array(
            	'dinero_page_text_color',
            	'dinero_page_links_color'
            ),
         )
    	),
	)));

	$wp_customize->add_setting('dinero_inner_pages_padding',array(
      'sanitize_callback'	=> 'esc_html'
   ));
   $wp_customize->add_control('dinero_inner_pages_padding',array(
      'label' => __('Section Padding','dinero'),
      'section' => 'dinero_inner_pages'
   ));

	$wp_customize->add_setting('dinero_page_top_padding',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_page_top_padding',array(
      'type' => 'number',
      'description' => __('Top','dinero'),
      'section' => 'dinero_inner_pages',
   ));

	$wp_customize->add_setting('dinero_page_bottom_padding',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_page_bottom_padding',array(
      'type' => 'number',
      'description' => __('Bottom','dinero'),
      'section' => 'dinero_inner_pages',
   ));

	$wp_customize->add_setting('dinero_page_sidebar',array(
  		'default' => 'No Sidebar',
     	'sanitize_callback' => 'dinero_sanitize_choices'
	));
	$wp_customize->add_control('dinero_page_sidebar',array(
     	'type' => 'select',
     	'label' => __('Page Sidebar Layout','dinero'),
     	'section' => 'dinero_inner_pages',
     	'choices' => array(
         'Left Sidebar' => __('Left Sidebar','dinero'),
         'Right Sidebar' => __('Right Sidebar','dinero'),
         'No Sidebar' => __('No Sidebar','dinero')
     	),
	));

	$wp_customize->add_setting( 'dinero_page_text_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_page_text_color', array(
  		'label' => __('Text Color','dinero'),
	   'section' => 'dinero_inner_pages',
  	)));

	$wp_customize->add_setting( 'dinero_page_links_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_page_links_color', array(
  		'label' => __('Links Color','dinero'),
	   'section' => 'dinero_inner_pages',
  	)));

	//Blog Page 
   $wp_customize->add_section( 'dinero_blog_page', array(
    	'title'  => __( 'Blog Page', 'dinero' ),
		'panel' => 'dinero_pages_parent_panel'
	) );

	$wp_customize->add_setting('dinero_reset_blog_page_settings',array(
      'sanitize_callback'	=> 'sanitize_text_field'
   ));
   $wp_customize->add_control(new Dinero_Reset_Custom_Control($wp_customize, 'dinero_reset_blog_page_settings',array(
      'type' => 'reset_control',
	   'priority' => 1,
      'label' => __('Reset Blog Settings', 'dinero'),
      'description' => 'dinero_reset_blog_post_settings',
      'section' => 'dinero_blog_page'
   )));

	$wp_customize->add_setting('dinero_blog_page_tabs', array(
	   'sanitize_callback' => 'wp_kses_post',
	));
	$wp_customize->add_control(new Dinero_Tab_Control($wp_customize, 'dinero_blog_page_tabs', array(
	   'section' => 'dinero_blog_page',
	   'priority' => 1,
	   'buttons' => array(
	      array(
	         'name' => esc_html__('General', 'dinero'),
            'fields' => array(
            	'header_image',
            	'dinero_show_date',
            	'dinero_show_author',
            	'dinero_show_comments',
            	'dinero_show_time',
            	'dinero_show_category',
            	'dinero_show_tags',
            	'dinero_blog_post_button_text'
            ),
            'active' => true,
         ),
	      array(
            'name' => esc_html__('Layout', 'dinero'),
            'fields' => array(
            	'dinero_show_thumbnail_image',
            	'dinero_blog_post_excerpt',
            	'dinero_blog_page_sidebar',
            	'dinero_blog_post_layout'
            ),
         ),
	      array(
            'name' => esc_html__('Style', 'dinero'),
            'fields' => array(
            	'dinero_blog_post_title_color',
            	'dinero_blog_post_text_color',
            	'dinero_blog_metabox_text_color',
            	'dinero_blog_metabox_icon_color',
            	'dinero_blog_metabox_bg_color',
            	'dinero_blog_post_button_text_color',
            	'dinero_blog_post_button_hover_color',
            	'dinero_blog_post_category_color',
            	'dinero_blog_post_category_icon_color',
            	'dinero_blog_post_tags_color',
            	'dinero_blog_post_tags_icon_color'
            ),
         )
    	),
	)));

	$wp_customize->get_control( 'header_image' )->section  = 'dinero_blog_page';

	$wp_customize->add_setting( 'dinero_show_date',array(
		'default' => false,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_date',array(
		'label' => __( 'Date','dinero' ),
	   'description' => __('It is a pro feature.','dinero'),
		'section' => 'dinero_blog_page'
   )));

	$wp_customize->add_setting( 'dinero_show_author',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_author',array(
		'label' => __( 'Author','dinero' ),
		'section' => 'dinero_blog_page'
   )));

	$wp_customize->add_setting( 'dinero_show_comments',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_comments',array(
		'label' => __( 'Comments','dinero' ),
		'section' => 'dinero_blog_page'
   )));

	$wp_customize->add_setting( 'dinero_show_time',array(
		'default' => false,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_time',array(
		'label' => __( 'Time','dinero' ),
	   'description' => __('It is a pro feature.','dinero'),
		'section' => 'dinero_blog_page'
   )));

	$wp_customize->add_setting( 'dinero_show_category',array(
		'default' => false,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_category',array(
		'label' => __( 'Category','dinero' ),
		'section' => 'dinero_blog_page'
   )));

	$wp_customize->add_setting( 'dinero_show_tags',array(
		'default' => false,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_tags',array(
		'label' => __( 'Tags','dinero' ),
		'section' => 'dinero_blog_page'
   )));

	$wp_customize->add_setting('dinero_blog_post_button_text',array(
    	'default' => __('Read More','dinero'),
    	'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('dinero_blog_post_button_text',array(
   	'type' => 'text',
   	'label' => __('Read More Button Label','dinero'),
   	'section' => 'dinero_blog_page',
	));

	$wp_customize->add_setting('dinero_blog_page_sidebar',array(
      'default' => 'Right Sidebar',
      'sanitize_callback' => 'dinero_sanitize_choices'
	));
	$wp_customize->add_control('dinero_blog_page_sidebar',array(
      'type' => 'select',
      'label' => __('Blog Sidebar','dinero'),
      'section' => 'dinero_blog_page',
      'choices' => array(
         'Left Sidebar' => __('Left Sidebar','dinero'),
         'Right Sidebar' => __('Right Sidebar','dinero'),
         'No Sidebar' => __('No Sidebar','dinero')
      ),
	));

	$wp_customize->add_setting('dinero_blog_post_excerpt',array(
    	'default' => 30,
		'sanitize_callback' => 'dinero_sanitize_integer'
	));
	$wp_customize->add_control(new Dinero_Custom_Control( $wp_customize, 'dinero_blog_post_excerpt',array(
   	'label' => __('Excerpt Length','dinero'),
   	'section' => 'dinero_blog_page',
   	'input_attrs' => array(
			'min' => 0,
			'max' => 100,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting('dinero_blog_post_layout',array(
      'default' => 'List View',
      'sanitize_callback' => 'dinero_sanitize_choices'
	));
	$wp_customize->add_control('dinero_blog_post_layout',array(
      'type' => 'select',
      'label' => __('Blog Layout','dinero'),
      'section' => 'dinero_blog_page',
      'choices' => array(
         'List View' => __('List View','dinero'),
         'Grid View' => __('Grid View','dinero')
      ),
	));

	$wp_customize->add_setting( 'dinero_show_thumbnail_image',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_thumbnail_image',array(
		'label' => __( 'Thumbnail Image','dinero' ),
		'section' => 'dinero_blog_page'
   )));

	$wp_customize->add_setting( 'dinero_blog_post_title_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_blog_post_title_color', array(
  		'label' => __('Blog Post Title Color','dinero'),
	   'section' => 'dinero_blog_page',
  	)));

	$wp_customize->add_setting( 'dinero_blog_post_text_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_blog_post_text_color', array(
  		'label' => __('Blog Post Content Color','dinero'),
	   'section' => 'dinero_blog_page',
  	)));

	$wp_customize->add_setting( 'dinero_blog_metabox_text_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_blog_metabox_text_color', array(
  		'label' => __('Blog Metabox Text Color','dinero'),
	   'section' => 'dinero_blog_page',
  	)));

	$wp_customize->add_setting( 'dinero_blog_metabox_icon_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_blog_metabox_icon_color', array(
  		'label' => __('Blog Metabox Icon Color','dinero'),
	   'section' => 'dinero_blog_page',
  	)));

	$wp_customize->add_setting( 'dinero_blog_metabox_bg_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_blog_metabox_bg_color', array(
  		'label' => __('Blog Metabox Background Color','dinero'),
	   'section' => 'dinero_blog_page',
  	)));

	$wp_customize->add_setting( 'dinero_blog_post_button_text_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_blog_post_button_text_color', array(
  		'label' => __('Button Text Color','dinero'),
	   'section' => 'dinero_blog_page',
  	)));

	$wp_customize->add_setting( 'dinero_blog_post_button_hover_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_blog_post_button_hover_color', array(
  		'label' => __('Button Text Hover Color','dinero'),
	   'section' => 'dinero_blog_page',
  	)));

	$wp_customize->add_setting( 'dinero_blog_post_category_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_blog_post_category_color', array(
  		'label' => __('Category Color','dinero'),
	   'section' => 'dinero_blog_page',
  	)));

	$wp_customize->add_setting( 'dinero_blog_post_category_icon_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_blog_post_category_icon_color', array(
  		'label' => __('Category Icon Color','dinero'),
	   'section' => 'dinero_blog_page',
  	)));

	$wp_customize->add_setting( 'dinero_blog_post_tags_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_blog_post_tags_color', array(
  		'label' => __('Tags Color','dinero'),
	   'section' => 'dinero_blog_page',
  	)));

	$wp_customize->add_setting( 'dinero_blog_post_tags_icon_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_blog_post_tags_icon_color', array(
  		'label' => __('Tags Icon Color','dinero'),
	   'section' => 'dinero_blog_page',
  	)));

	//Single Post Page
 	$wp_customize->add_section( 'dinero_single_post_page', array(
    	'title'  => __( 'Single Post Page', 'dinero' ),
		'priority' => null,
		'panel' => 'dinero_pages_parent_panel'
	) );

	$wp_customize->add_setting('dinero_reset_single_post_settings',array(
      'sanitize_callback'	=> 'sanitize_text_field'
   ));
   $wp_customize->add_control(new Dinero_Reset_Custom_Control($wp_customize, 'dinero_reset_single_post_settings',array(
      'type' => 'reset_control',
	   'priority' => 1,
      'label' => __('Reset Single Post Settings', 'dinero'),
      'description' => 'dinero_single_post_reset_settings',
      'section' => 'dinero_single_post_page'
   )));

	$wp_customize->add_setting('dinero_single_post_tabs', array(
	   'sanitize_callback' => 'wp_kses_post',
	));
	$wp_customize->add_control(new Dinero_Tab_Control($wp_customize, 'dinero_single_post_tabs', array(
	   'section' => 'dinero_single_post_page',
	   'priority' => 1,
	   'buttons' => array(
	      array(
	         'name' => esc_html__('General', 'dinero'),
            'fields' => array(
            	'dinero_show_featured_image',
            	'dinero_single_post_image_height',
            	'dinero_single_post_sidebar',
            	'dinero_show_single_post_date',
            	'dinero_show_single_post_author',
            	'dinero_show_single_post_comments',
            	'dinero_single_post_time',
            	'dinero_show_single_post_category',
            	'dinero_show_single_post_tags',
            	'dinero_show_share_icons'
            ),
            'active' => true,
         ),
	      array(
            'name' => esc_html__('Style', 'dinero'),
            'fields' => array(
            	'dinero_single_post_metabox_bg_color',
            	'dinero_single_post_metabox_text_color',
            	'dinero_single_post_metabox_icon_color',
            	'dinero_single_post_category_color',
            	'dinero_single_post_category_icon_color',
            	'dinero_single_post_tags_icon_color',
            	'dinero_single_post_tags_color',
            	'dinero_single_post_title_color',
            	'dinero_single_post_content_color',
            	'dinero_single_post_comment_title_color',
            	'dinero_single_post_comment_text_color',
            	'dinero_single_post_comment_date_color'
            ),
         )
    	),
	)));

	$wp_customize->add_setting( 'dinero_show_featured_image',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_featured_image',array(
		'label' => __( 'Featured Image','dinero' ),
		'section' => 'dinero_single_post_page'
   )));

	$wp_customize->add_setting('dinero_single_post_image_height',array(
    	'default' => '350',
		'sanitize_callback' => 'dinero_sanitize_integer'
	));
	$wp_customize->add_control(new Dinero_Custom_Control( $wp_customize, 'dinero_single_post_image_height',array(
   	'label' => __('Featured Image Height','dinero'),
   	'section' => 'dinero_single_post_page',
   	'input_attrs' => array(
			'min' => 0,
			'max' => 1000,
			'step' => 5,
		),
	)));

	$wp_customize->add_setting('dinero_single_post_sidebar',array(
     	'default' => 'Right Sidebar',
     	'sanitize_callback' => 'dinero_sanitize_choices'
	));
	$wp_customize->add_control('dinero_single_post_sidebar',array(
     	'type' => 'select',
     	'label' => __('Single Post Sidebar Layout','dinero'),
     	'section' => 'dinero_single_post_page',
     	'choices' => array(
         'Left Sidebar' => __('Left Sidebar','dinero'),
         'Right Sidebar' => __('Right Sidebar','dinero'),
         'One Column' => __('One Column','dinero')
     	),
	));

	$wp_customize->add_setting( 'dinero_show_single_post_date',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_single_post_date',array(
		'label' => __( 'Date','dinero' ),
	   'description' => __('It is a pro feature.','dinero'),
		'section' => 'dinero_single_post_page'
   )));

	$wp_customize->add_setting( 'dinero_show_single_post_author',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_single_post_author',array(
		'label' => __( 'Author','dinero' ),
		'section' => 'dinero_single_post_page'
   )));

	$wp_customize->add_setting( 'dinero_show_single_post_comments',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_single_post_comments',array(
		'label' => __( 'Comments','dinero' ),
		'section' => 'dinero_single_post_page'
   )));

	$wp_customize->add_setting( 'dinero_single_post_time',array(
		'default' => false,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_single_post_time',array(
		'label' => __( 'Time','dinero' ),
	   'description' => __('It is a pro feature.','dinero'),
		'section' => 'dinero_single_post_page'
   )));

	$wp_customize->add_setting( 'dinero_show_single_post_category',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_single_post_category',array(
		'label' => __( 'Category','dinero' ),
		'section' => 'dinero_single_post_page'
   )));

	$wp_customize->add_setting( 'dinero_show_single_post_tags',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_single_post_tags',array(
		'label' => __( 'Tags','dinero' ),
		'section' => 'dinero_single_post_page'
   )));

	$wp_customize->add_setting( 'dinero_show_share_icons',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_share_icons',array(
		'label' => __( 'Share Icons','dinero' ),
	   'description' => __('It is a pro feature.','dinero'),
		'section' => 'dinero_single_post_page'
   )));

	$wp_customize->add_setting( 'dinero_single_post_title_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_single_post_title_color', array(
  		'label' => __('Title Color','dinero'),
	   'section' => 'dinero_single_post_page',
  	)));

	$wp_customize->add_setting( 'dinero_single_post_content_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_single_post_content_color', array(
  		'label' => __('Content Color','dinero'),
	   'section' => 'dinero_single_post_page',
  	)));

	$wp_customize->add_setting( 'dinero_single_post_metabox_bg_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_single_post_metabox_bg_color', array(
  		'label' => __('Metabox Background Color','dinero'),
	   'section' => 'dinero_single_post_page',
  	)));

	$wp_customize->add_setting( 'dinero_single_post_metabox_text_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_single_post_metabox_text_color', array(
  		'label' => __('Metabox Text Color','dinero'),
	   'section' => 'dinero_single_post_page',
  	)));

	$wp_customize->add_setting( 'dinero_single_post_metabox_icon_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_single_post_metabox_icon_color', array(
  		'label' => __('Metabox Icon Color','dinero'),
	   'section' => 'dinero_single_post_page',
  	)));

	$wp_customize->add_setting( 'dinero_single_post_category_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_single_post_category_color', array(
  		'label' => __('Category Color','dinero'),
	   'section' => 'dinero_single_post_page',
  	)));

	$wp_customize->add_setting( 'dinero_single_post_category_icon_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_single_post_category_icon_color', array(
  		'label' => __('Category Icon Color','dinero'),
	   'section' => 'dinero_single_post_page',
  	)));

	$wp_customize->add_setting( 'dinero_single_post_tags_icon_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_single_post_tags_icon_color', array(
  		'label' => __('Tags Icon Color','dinero'),
	   'section' => 'dinero_single_post_page',
  	)));

	$wp_customize->add_setting( 'dinero_single_post_tags_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_single_post_tags_color', array(
  		'label' => __('Tags Color','dinero'),
	   'section' => 'dinero_single_post_page',
  	)));

	$wp_customize->add_setting( 'dinero_single_post_comment_title_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_single_post_comment_title_color', array(
  		'label' => __('Comment Title Color','dinero'),
	   'section' => 'dinero_single_post_page',
  	)));

	$wp_customize->add_setting( 'dinero_single_post_comment_text_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_single_post_comment_text_color', array(
  		'label' => __('Comment Text Color','dinero'),
	   'section' => 'dinero_single_post_page',
  	)));

	$wp_customize->add_setting( 'dinero_single_post_comment_date_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_single_post_comment_date_color', array(
  		'label' => __('Comment Date Color','dinero'),
	   'section' => 'dinero_single_post_page',
  	)));

	//Other Settings
	$OtherParentPanel = new Dinero_WP_Customize_Panel( $wp_customize, 'dinero_other_settings', array(
		'title' => esc_html__( 'Other Settings', 'dinero' ),
		'panel' => 'dinero_panel_id1',
		'priority' => 11,
	));

	$wp_customize->add_panel( $OtherParentPanel );

	$wp_customize->add_section( 'dinero_font_settings' , array(
    	'title' => __( 'Font Settings', 'dinero' ),
		'panel' => 'dinero_other_settings'
	) );

	$dinero_fonts = array(
		'' => 'No Fonts',
		'Abril Fatface' => 'Abril Fatface', 
		'Acme' => 'Acme', 
		'Anton' => 'Anton',
		'Architects Daughter' =>'Architects Daughter', 
		'Arimo' => 'Arimo', 
		'Arsenal' => 'Arsenal', 
		'Arvo' => 'Arvo', 
		'Alegreya' => 'Alegreya',
		'Alfa Slab One' =>  'Alfa Slab One', 
		'Averia Serif Libre' =>  'Averia Serif Libre',
		'Bangers' => 'Bangers', 
		'Boogaloo' => 'Boogaloo',
		'Bad Script' => 'Bad Script', 
		'Bitter' =>  'Bitter', 
		'Bree Serif' => 'Bree Serif', 
		'BenchNine' => 'BenchNine',
		'Cabin' => 'Cabin', 
		'Cardo' => 'Cardo', 
		'Courgette' => 'Courgette', 
		'Cherry Swash' => 'Cherry Swash', 
		'Cormorant Garamond' => 'Cormorant Garamond', 
		'Crimson Text' => 'Crimson Text',
		'Cuprum' => 'Cuprum', 
		'Cookie' => 'Cookie', 
		'Chewy' => 'Chewy', 
		'Days One' => 'Days One',
		'Dosis' => 'Dosis', 
		'Droid Sans' => 'Droid Sans',
		'Economica' =>  'Economica',
		'Fredoka One' => 'Fredoka One', 
		'Fjalla One' => 'Fjalla One', 
		'Francois One' => 'Francois One', 
		'Frank Ruhl Libre' => 'Frank Ruhl Libre', 
		'Gloria Hallelujah' => 'Gloria Hallelujah',
		'Great Vibes' =>  'Great Vibes', 
		'Handlee' => 'Handlee',
		'Hammersmith One' =>'Hammersmith One', 
		'Inconsolata' => 'Inconsolata', 
		'Indie Flower' => 'Indie Flower', 
		'IM Fell English SC' => 'IM Fell English SC',
		'Julius Sans One' => 'Julius Sans One', 
		'Josefin Slab' => 'Josefin Slab', 
		'Josefin Sans' => 'Josefin Sans',
		'Kanit' => 'Kanit', 
		'Lobster' =>  'Lobster', 
		'Lato' => 'Lato', 
		'Lora' =>'Lora',
		'Libre Baskerville' =>  'Libre Baskerville', 
		'Lobster Two' => 'Lobster Two',
		'Merriweather' => 'Merriweather', 
		'Monda' => 'Monda', 
		'Montserrat' => 'Montserrat', 
		'Muli' => 'Muli', 
		'Marck Script' => 'Marck Script', 
		'Noto Serif' => 'Noto Serif', 
		'Open Sans' => 'Open Sans', 
		'Overpass' => 'Overpass', 
		'Overpass Mono' =>  'Overpass Mono', 
		'Oxygen' => 'Oxygen', 
		'Orbitron' => 'Orbitron',
		'Patua One' => 'Patua One', 
		'Pacifico' =>  'Pacifico',
		'Padauk' => 'Padauk',
		'Playball' =>  'Playball', 
		'Playfair Display' => 'Playfair Display',
		'PT Sans' => 'PT Sans', 
		'Philosopher' => 'Philosopher', 
		'Permanent Marker' => 'Permanent Marker', 
		'Poiret One' => 'Poiret One', 
		'Quicksand' => 'Quicksand', 
		'Quattrocento Sans' =>'Quattrocento Sans',
		'Raleway' => 'Raleway', 
		'Rubik' => 'Rubik', 
		'Rokkitt' => 'Rokkitt', 
		'Russo One' => 'Russo One', 
		'Righteous' => 'Righteous', 
		'Slabo' => 'Slabo', 
		'Source Sans Pro' => 'Source Sans Pro',
		'Shadows Into Light Two' => 'Shadows Into Light Two',
		'Shadows Into Light' => 'Shadows Into Light',
		'Sacramento' => 'Sacramento', 
		'Shrikhand' => 'Shrikhand',
		'Tangerine' => 'Tangerine', 
		'Ubuntu' => 'Ubuntu', 
		'VT323' => 'VT323', 
		'Varela Round' => 'Varela Round',
		'Vampiro One' => 'Vampiro One', 
		'Vollkorn' => 'Vollkorn', 
		'Volkhov' => 'Volkhov', 
		'Yanone Kaffeesatz' =>'Yanone Kaffeesatz', 
 	);

	$wp_customize->add_setting('dinero_heading_font_family',array(
	  'default' => '',
	  'sanitize_callback' => 'dinero_sanitize_choices'
	));
	$wp_customize->add_control(
		'dinero_heading_font_family', array(
		'section'  => 'dinero_font_settings',
		'label'    => __( 'Heading Fonts','dinero'),
		'type'     => 'select',
		'choices'  => $dinero_fonts,
	));

	$wp_customize->add_setting('dinero_body_font_family',array(
	  'default' => '',
	  'sanitize_callback' => 'dinero_sanitize_choices'
	));
	$wp_customize->add_control(
		'dinero_body_font_family', array(
		'section'  => 'dinero_font_settings',
		'label'    => __( 'Body Fonts','dinero'),
		'type'     => 'select',
		'choices'  => $dinero_fonts,
	));

	$wp_customize->add_section( 'dinero_breadcrumb_options' , array(
    	'title' => __( 'Breadcrumb Options', 'dinero' ),
		'panel' => 'dinero_other_settings'
	) );

	$wp_customize->add_setting( 'dinero_show_breadcrumb',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_show_breadcrumb',array(
		'label' => __( 'Breadcrumb','dinero' ),
		'section' => 'dinero_breadcrumb_options'
   )));

	$wp_customize->add_setting( 'dinero_breadcrumb_text_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_breadcrumb_text_color', array(
  		'label' => __('Text Color','dinero'),
	   'section' => 'dinero_breadcrumb_options',
  	)));

	$wp_customize->add_setting( 'dinero_breadcrumb_active_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_breadcrumb_active_color', array(
  		'label' => __('Active Color','dinero'),
	   'section' => 'dinero_breadcrumb_options',
  	)));

	$wp_customize->add_setting( 'dinero_breadcrumb_hover_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_breadcrumb_hover_color', array(
  		'label' => __('Hover Color','dinero'),
	   'section' => 'dinero_breadcrumb_options',
  	)));

   //add home page setting pannel
	$dinero_parent_panel2 = new Dinero_WP_Customize_Panel( $wp_customize, 'dinero_panel_id2', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'Home Sections', 'dinero' ),
		'priority' => 10,
	));

	$wp_customize->add_panel( $dinero_parent_panel2 );

	//home page slider
	$wp_customize->add_section( 'dinero_slider_section' , array(
    	'title'    => __( 'Slider Settings', 'dinero' ),
		'priority' => null,
		'panel' => 'dinero_panel_id2'
	) );

	$wp_customize->add_setting('dinero_reset_slider_settings',array(
      'sanitize_callback'	=> 'sanitize_text_field'
   ));
   $wp_customize->add_control(new Dinero_Reset_Custom_Control($wp_customize, 'dinero_reset_slider_settings',array(
      'type' => 'reset_control',
	   'priority' => 1,
      'label' => __('Reset Slider Settings', 'dinero'),
      'description' => 'dinero_slider_reset_settings',
      'section' => 'dinero_slider_section'
   )));

	$wp_customize->add_setting('dinero_slider_section_option',array(
     'default' => 'Luzuk Slider',
     'sanitize_callback' => 'dinero_sanitize_choices'
	));
	$wp_customize->add_control('dinero_slider_section_option',array(
      'type' => 'select',
      'label' => __('Slider Type','dinero'),
      'section' => 'dinero_slider_section',
      'choices' => array(
         'Luzuk Slider' => __('Luzuk Slider','dinero'),
         'Other Plugin Slider' => __('Other Plugin Slider','dinero')
      ),
	));

	$wp_customize->add_setting('dinero_slider_shortcode',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('dinero_slider_shortcode',array(
   	'type' => 'text',
   	'label' => __('Add Slider Shortcode','dinero'),
   	'section' => 'dinero_slider_section',
   	'active_callback' => 'dinero_shortcode_enabled'
	));

	$wp_customize->add_setting('dinero_slider_section_width',array(
		'default' => 'Full Width',
		'sanitize_callback' => 'dinero_sanitize_choices',
	));
	$wp_customize->add_control('dinero_slider_section_width',array(
		'type' => 'select',
		'label' => __('Section Width','dinero'),
		'choices' => array (
			'Box Width' => __('Box Width','dinero'),
			'Full Width' => __('Full Width','dinero')
		),
		'section' => 'dinero_slider_section',
	));

	//services Section
	$wp_customize->add_section('dinero_service_section',array(
		'title'	=> __('Services','dinero'),
		'panel' => 'dinero_panel_id2',
	));

	$wp_customize->add_setting('dinero_reset_service_settings',array(
      'sanitize_callback'	=> 'sanitize_text_field'
   ));
   $wp_customize->add_control(new Dinero_Reset_Custom_Control($wp_customize, 'dinero_reset_service_settings',array(
      'type' => 'reset_control',
	   'priority' => 1,
      'label' => __('Reset Service Section Settings', 'dinero'),
      'description' => 'dinero_services_reset_settings',
      'section' => 'dinero_service_section'
   )));

	$wp_customize->add_setting('dinero_service_section_tabs', array(
	   'sanitize_callback' => 'wp_kses_post',
	));
	$wp_customize->add_control(new Dinero_Tab_Control($wp_customize, 'dinero_service_section_tabs', array(
	   'section' => 'dinero_service_section',
	   'priority' => 1,
	   'buttons' => array(
	      array(
	         'name' => esc_html__('General', 'dinero'),
            'fields' => array(
            	'dinero_service_enable',
            	'dinero_service_section_small_title',
            	'dinero_service_section_title',
            	'dinero_service_number',
            	'dinero_service_icon1',
            	'dinero_service_icon2',
            	'dinero_service_icon3',
            	'dinero_service_icon4',
            	'dinero_service_icon5',
            	'dinero_service_icon6',
            	'dinero_service_icon7',
            	'dinero_service_icon8',
            	'dinero_service_type',
            	'dinero_service_page1',
            	'dinero_service_page2',
            	'dinero_service_page3',
            	'dinero_service_page4',
            	'dinero_service_page5',
            	'dinero_service_page6',
            	'dinero_service_page7',
            	'dinero_service_page8',
            	'dinero_service_post1',
            	'dinero_service_post2',
            	'dinero_service_post3',
            	'dinero_service_post4',
            	'dinero_service_post5',
            	'dinero_service_post6',
            	'dinero_service_post7',
            	'dinero_service_post8',
            	'dinero_service_button_enable'
            ),
            'active' => true,
         ),
	      array(
            'name' => esc_html__('Layout', 'dinero'),
            'fields' => array(
            	'dinero_service_section_width',
            	'dinero_service_section_columns'
            ),
         ),
	      array(
            'name' => esc_html__('Style', 'dinero'),
            'fields' => array(
            	'dinero_service_section_padding',
            	'dinero_service_top_padding',
            	'dinero_service_bottom_padding',
            	'dinero_service_left_padding',
            	'dinero_service_right_padding',
            	'dinero_service_section_bg_color',
            	'dinero_service_section_bg_image',
            	'dinero_service_bg_opacity',
            	'dinero_service_onload_effects',
            	'dinero_service_small_title_color',
            	'dinero_service_section_title_color',
            	'dinero_service_section_icon_color',
            	'dinero_service_title_color',
            	'dinero_service_text_color',
            	'dinero_service_button_color',
            	'dinero_service_button_hover_color',
            	'dinero_service_box_color',
            	'dinero_service_box_hover_color'
            ),
         )
    	),
	)));

	$wp_customize->add_setting( 'dinero_service_enable',array(
		'default' => false,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_service_enable',array(
		'label' => __( 'Service Section','dinero' ),
		'section' => 'dinero_service_section'
   )));

	$wp_customize->add_setting('dinero_service_number',array(
		'default' => '6',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('dinero_service_number',array(
		'label' => __('Number of services to show','dinero'),
		'input_attrs' => array(
         'step' => 1,
			'min' => 0,
			'max' => 8,
      ),
		'section' => 'dinero_service_section',
		'type' => 'number'
	));

	$wp_customize->add_setting('dinero_service_section_small_title',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('dinero_service_section_small_title',array(
   	'type' => 'text',
   	'label' => __('Add Section Small Title','dinero'),
   	'section' => 'dinero_service_section',
	));

	$wp_customize->add_setting('dinero_service_section_title',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('dinero_service_section_title',array(
   	'type' => 'text',
   	'label' => __('Add Section Title','dinero'),
   	'section' => 'dinero_service_section',
	));

	$wp_customize->add_setting('dinero_service_type',array(
		'default' => 'With Posts',
		'sanitize_callback' => 'dinero_sanitize_choices',
	));
	$wp_customize->add_control('dinero_service_type',array(
		'type' => 'select',
		'label' => __('Display Services','dinero'),
		'choices' => array (
			'With Posts' => __('With Posts','dinero'),
			'With Pages' => __('With Pages','dinero')
		),
		'section' => 'dinero_service_section',
	));

	$dinero_service_number = get_theme_mod('dinero_service_number', 6);

	for ( $count = 1; $count <= $dinero_service_number; $count++ ) {
		$wp_customize->add_setting( 'dinero_service_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'dinero_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'dinero_service_page' . $count, array(
			'label'    => __( 'Select Service Page ', 'dinero') . $count,
			'section'  => 'dinero_service_section',
			'type'     => 'dropdown-pages',
			'active_callback' => 'dinero_service_type_pages'
		) );

		$args =  array('numberposts' => -1);
		$post_list = get_posts($args);
		$i = 0;
		$psts[]='Select';  
		foreach($post_list as $post){
			$psts[$post->post_title] = $post->post_title;
		}

		$wp_customize->add_setting('dinero_service_post' . $count, array(
			'sanitize_callback' => 'dinero_sanitize_choices',
		));
		$wp_customize->add_control('dinero_service_post' . $count, array(
			'type'    => 'select',
			'choices' => $psts,
			'label' => __('Select Service Post ','dinero') . $count,
			'section' => 'dinero_service_section',
			'active_callback' => 'dinero_service_type_posts'
		));

		$wp_customize->add_setting('dinero_service_icon' . $count, array(
	      'default' => 'far fa-chart-bar',
	      'sanitize_callback' => 'sanitize_text_field'
	   ));
	   $wp_customize->add_control(new Dinero_Fontawesome_Icon_Chooser($wp_customize, 'dinero_service_icon' . $count, array(
	      'section' => 'dinero_service_section',
	      'type' => 'icon',
	      'label' => __('Service Icon ', 'dinero') . $count
	   )));
	}

	$wp_customize->add_setting( 'dinero_service_button_enable',array(
		'default' => true,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_service_button_enable',array(
		'label' => __( 'Service Button','dinero' ),
		'section' => 'dinero_service_section'
   )));

	$wp_customize->add_setting('dinero_service_section_width',array(
		'default' => 'Box Width',
		'sanitize_callback' => 'dinero_sanitize_choices',
	));
	$wp_customize->add_control('dinero_service_section_width',array(
		'type' => 'select',
		'label' => __('Section Width','dinero'),
		'choices' => array (
			'Box Width' => __('Box Width','dinero'),
			'Full Width' => __('Full Width','dinero')
		),
		'section' => 'dinero_service_section',
	));

	$wp_customize->add_setting('dinero_service_section_padding',array(
      'sanitize_callback'	=> 'esc_html'
   ));
   $wp_customize->add_control('dinero_service_section_padding',array(
      'label' => __('Section Padding','dinero'),
      'section' => 'dinero_service_section'
   ));

	$wp_customize->add_setting('dinero_service_top_padding',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_service_top_padding',array(
      'type' => 'number',
      'description' => __('Top','dinero'),
      'section' => 'dinero_service_section',
   ));

	$wp_customize->add_setting('dinero_service_bottom_padding',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_service_bottom_padding',array(
      'type' => 'number',
      'description' => __('Bottom','dinero'),
      'section' => 'dinero_service_section',
   ));

	$wp_customize->add_setting('dinero_service_left_padding',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_service_left_padding',array(
      'type' => 'number',
      'description' => __('Left','dinero'),
      'section' => 'dinero_service_section',
   ));

	$wp_customize->add_setting('dinero_service_right_padding',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_service_right_padding',array(
      'type' => 'number',
      'description' => __('Right','dinero'),
      'section' => 'dinero_service_section',
   ));

	$wp_customize->add_setting( 'dinero_service_section_bg_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_service_section_bg_color', array(
  		'label' => __('Section Background Color','dinero'),
	   'section' => 'dinero_service_section',
  	)));

	$wp_customize->add_setting( 'dinero_service_section_bg_image', array(
	   'default' => '',
	   'sanitize_callback' => 'esc_url_raw'
  	));
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'dinero_service_section_bg_image', array(
  		'label' => __('Section Background Image','dinero'),
	   'section' => 'dinero_service_section',
  	)));

	$wp_customize->add_setting('dinero_service_bg_opacity',array(
    	'default' => 1,
		'sanitize_callback' => 'dinero_sanitize_float'
	));
	$wp_customize->add_control(new Dinero_Custom_Control( $wp_customize, 'dinero_service_bg_opacity',array(
   	'label' => __('Background Opacity','dinero'),
   	'section' => 'dinero_service_section',
   	'input_attrs' => array(
			'min' => 0,
			'max' => 1,
			'step' => 0.1,
		),
	)));

	$wp_customize->add_setting( 'dinero_service_small_title_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_service_small_title_color', array(
  		'label' => __('Small title Color','dinero'),
	   'section' => 'dinero_service_section',
  	)));

	$wp_customize->add_setting( 'dinero_service_section_title_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_service_section_title_color', array(
  		'label' => __('Section Title Color','dinero'),
	   'section' => 'dinero_service_section',
  	)));

	$wp_customize->add_setting( 'dinero_service_section_icon_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_service_section_icon_color', array(
  		'label' => __('Service Icon Color','dinero'),
	   'section' => 'dinero_service_section',
  	)));

	$wp_customize->add_setting( 'dinero_service_title_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_service_title_color', array(
  		'label' => __('Service Title Color','dinero'),
	   'section' => 'dinero_service_section',
  	)));

	$wp_customize->add_setting( 'dinero_service_text_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_service_text_color', array(
  		'label' => __('Service Text Color','dinero'),
	   'section' => 'dinero_service_section',
  	)));

	$wp_customize->add_setting( 'dinero_service_button_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_service_button_color', array(
  		'label' => __('Service Button Color','dinero'),
	   'section' => 'dinero_service_section',
  	)));

	$wp_customize->add_setting( 'dinero_service_button_hover_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_service_button_hover_color', array(
  		'label' => __('Service Button Hover Color','dinero'),
	   'section' => 'dinero_service_section',
  	)));

	$wp_customize->add_setting( 'dinero_service_box_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_service_box_color', array(
  		'label' => __('Service Box Color','dinero'),
	   'section' => 'dinero_service_section',
  	)));

	$wp_customize->add_setting( 'dinero_service_box_hover_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_service_box_hover_color', array(
  		'label' => __('Service Box Hover Color','dinero'),
	   'section' => 'dinero_service_section',
  	)));

  	$wp_customize->add_setting('dinero_service_onload_effects',array(
		'default' => 'zoomInUp',
		'sanitize_callback' => 'dinero_sanitize_choices',
	));
	$wp_customize->add_control('dinero_service_onload_effects',array(
		'type' => 'select',
		'label' => __('Onload Transition Effects','dinero'),
		'choices' => array (
			'zoomInUp' => __('Zoom In Up','dinero'),
			'fadeInUp' => __('Fade In Up','dinero'),
			'slideInLeft' => __('Slide In Left','dinero'),
			'slideInRight' => __('Slide In Right','dinero'),
			'slideInUp' => __('Slide In Up','dinero')
		),
		'section' => 'dinero_service_section',
	));

	//About Section
	$wp_customize->add_section('dinero_about_section',array(
		'title'	=> __('About Section','dinero'),
		'panel' => 'dinero_panel_id2',
	));

	$wp_customize->add_setting('dinero_reset_about_section',array(
      'sanitize_callback'	=> 'sanitize_text_field'
   ));
   $wp_customize->add_control(new Dinero_Reset_Custom_Control($wp_customize, 'dinero_reset_about_section',array(
      'type' => 'reset_control',
	   'priority' => 1,
      'label' => __('Reset About Section Settings', 'dinero'),
      'description' => 'dinero_about_reset_settings',
      'section' => 'dinero_about_section'
   )));

	$wp_customize->add_setting('dinero_about_section_tabs', array(
	   'sanitize_callback' => 'wp_kses_post',
	));
	$wp_customize->add_control(new Dinero_Tab_Control($wp_customize, 'dinero_about_section_tabs', array(
	   'section' => 'dinero_about_section',
	   'priority' => 1,
	   'buttons' => array(
	      array(
	         'name' => esc_html__('General', 'dinero'),
            'fields' => array(
            	'dinero_about_enable',
            	'dinero_about_section_width',
            	'dinero_about_image',
            	'dinero_about_section_title1',
            	'dinero_about_section_title2',
            	'dinero_about_section_text',
            	'dinero_about_noof_list',
            	'dinero_about_list1',
            	'dinero_about_list2',
            	'dinero_about_list3',
            	'dinero_about_list4',
            	'dinero_about_list5',
            	'dinero_about_list6',
            	'dinero_about_list7',
            	'dinero_about_list8',
            	'dinero_about_section_button_text',
            	'dinero_about_section_button_url'
            ),
            'active' => true,
         ),
	      array(
            'name' => esc_html__('Style', 'dinero'),
            'fields' => array(
            	'dinero_about_section_padding',
            	'dinero_about_top_padding',
            	'dinero_about_bottom_padding',
            	'dinero_about_left_padding',
            	'dinero_about_right_padding',
            	'dinero_about_section_bg_color',
            	'dinero_about_section_bg_image',
            	'dinero_about_bg_opacity',
            	'dinero_about_onload_effects',
            	'dinero_about_small_title_color',
            	'dinero_about_section_title_color',
            	'dinero_about_section_text_color',
            	'dinero_about_section_list_color',
            	'dinero_about_button_bg_color',
            	'dinero_about_button_hover_bg_color',
            	'dinero_about_button_color'
            ),
         )
    	),
	)));

	$wp_customize->add_setting( 'dinero_about_enable',array(
		'default' => false,
		'sanitize_callback' => 'dinero_switch_sanitization'
   ) );
   $wp_customize->add_control( new Dinero_Toggle_Switch_Custom_Control( $wp_customize, 'dinero_about_enable',array(
		'label' => __( 'About Section','dinero' ),
		'section' => 'dinero_about_section'
   )));

	$wp_customize->add_setting('dinero_about_section_width',array(
		'default' => 'Full Width',
		'sanitize_callback' => 'dinero_sanitize_choices',
	));
	$wp_customize->add_control('dinero_about_section_width',array(
		'type' => 'select',
		'label' => __('Section Width','dinero'),
		'choices' => array (
			'Box Width' => __('Box Width','dinero'),
			'Full Width' => __('Full Width','dinero')
		),
		'section' => 'dinero_about_section',
	));

	$wp_customize->add_setting( 'dinero_about_image', array(
	   'default' => '',
	   'sanitize_callback' => 'esc_url_raw'
  	));
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'dinero_about_image', array(
  		'label' => __('About Image','dinero'),
	   'section' => 'dinero_about_section',
  	)));

	$wp_customize->add_setting('dinero_about_section_title1',array(
    	'default' => '',
    	'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('dinero_about_section_title1',array(
   	'type' => 'text',
   	'label' => __('Section Title 1','dinero'),
   	'section' => 'dinero_about_section',
	));

	$wp_customize->add_setting('dinero_about_section_title2',array(
    	'default' => '',
    	'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('dinero_about_section_title2',array(
   	'type' => 'text',
   	'label' => __('Section Title 2','dinero'),
   	'section' => 'dinero_about_section',
	));

	$wp_customize->add_setting('dinero_about_section_text',array(
    	'default' => '',
    	'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('dinero_about_section_text',array(
   	'type' => 'text',
   	'label' => __('Section Text','dinero'),
   	'section' => 'dinero_about_section',
	));

	$wp_customize->add_setting('dinero_about_noof_list',array(
		'default' => '4',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('dinero_about_noof_list',array(
		'label' => __('Number of lists to show','dinero'),
		'input_attrs' => array(
         'step' => 1,
			'min' => 0,
			'max' => 8,
      ),
		'section' => 'dinero_about_section',
		'type' => 'number'
	));

	$dinero_about_noof_list = get_theme_mod('dinero_about_noof_list',4);
	for ($i=1; $i <= $dinero_about_noof_list; $i++) { 
		$wp_customize->add_setting('dinero_about_list'.$i,array(
	    	'default' => '',
	    	'sanitize_callback' => 'sanitize_text_field'
		));
		$wp_customize->add_control('dinero_about_list'.$i,array(
	   	'type' => 'text',
	   	'label' => __('List no. ','dinero').$i,
	   	'section' => 'dinero_about_section',
		));
	}

	$wp_customize->add_setting('dinero_about_section_button_text',array(
    	'default' => '',
    	'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('dinero_about_section_button_text',array(
   	'type' => 'text',
   	'label' => __('Button Text','dinero'),
   	'section' => 'dinero_about_section',
	));

	$wp_customize->add_setting('dinero_about_section_button_url',array(
    	'default' => '',
    	'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('dinero_about_section_button_url',array(
   	'type' => 'text',
   	'label' => __('Button Link','dinero'),
   	'section' => 'dinero_about_section',
	));

	$wp_customize->add_setting('dinero_about_section_padding',array(
      'sanitize_callback'	=> 'esc_html'
   ));
   $wp_customize->add_control('dinero_about_section_padding',array(
      'label' => __('Section Padding','dinero'),
      'section' => 'dinero_about_section'
   ));

	$wp_customize->add_setting('dinero_about_top_padding',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_about_top_padding',array(
      'type' => 'number',
      'description' => __('Top','dinero'),
      'section' => 'dinero_about_section',
   ));

	$wp_customize->add_setting('dinero_about_bottom_padding',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_about_bottom_padding',array(
      'type' => 'number',
      'description' => __('Bottom','dinero'),
      'section' => 'dinero_about_section',
   ));

	$wp_customize->add_setting('dinero_about_left_padding',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_about_left_padding',array(
      'type' => 'number',
      'description' => __('Left','dinero'),
      'section' => 'dinero_about_section',
   ));

	$wp_customize->add_setting('dinero_about_right_padding',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_about_right_padding',array(
      'type' => 'number',
      'description' => __('Right','dinero'),
      'section' => 'dinero_about_section',
   ));

	$wp_customize->add_setting( 'dinero_about_section_bg_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_about_section_bg_color', array(
  		'label' => __('Section Background Color','dinero'),
	   'section' => 'dinero_about_section',
  	)));

	$wp_customize->add_setting( 'dinero_about_section_bg_image', array(
	   'default' => '',
	   'sanitize_callback' => 'esc_url_raw'
  	));
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'dinero_about_section_bg_image', array(
  		'label' => __('Section Background Image','dinero'),
	   'section' => 'dinero_about_section'
  	)));

	$wp_customize->add_setting('dinero_about_bg_opacity',array(
    	'default' => 1,
		'sanitize_callback' => 'dinero_sanitize_float'
	));
	$wp_customize->add_control(new Dinero_Custom_Control( $wp_customize, 'dinero_about_bg_opacity',array(
   	'label' => __('Background Opacity','dinero'),
   	'section' => 'dinero_about_section',
   	'input_attrs' => array(
			'min' => 0,
			'max' => 1,
			'step' => 0.1,
		),
	)));

	$wp_customize->add_setting( 'dinero_about_small_title_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_about_small_title_color', array(
  		'label' => __('Section Title 1 Color','dinero'),
	   'section' => 'dinero_about_section',
  	)));

	$wp_customize->add_setting( 'dinero_about_section_title_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_about_section_title_color', array(
  		'label' => __('Section Title 2 Color','dinero'),
	   'section' => 'dinero_about_section',
  	)));

	$wp_customize->add_setting( 'dinero_about_section_text_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_about_section_text_color', array(
  		'label' => __('Section Text Color','dinero'),
	   'section' => 'dinero_about_section',
  	)));

	$wp_customize->add_setting( 'dinero_about_section_list_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_about_section_list_color', array(
  		'label' => __('Section List Color','dinero'),
	   'section' => 'dinero_about_section',
  	)));

	$wp_customize->add_setting( 'dinero_about_button_bg_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_about_button_bg_color', array(
  		'label' => __('Button Background Color','dinero'),
	   'section' => 'dinero_about_section',
  	)));

	$wp_customize->add_setting( 'dinero_about_button_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_about_button_color', array(
  		'label' => __('Button Color','dinero'),
	   'section' => 'dinero_about_section',
  	)));

	$wp_customize->add_setting( 'dinero_about_button_hover_bg_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_about_button_hover_bg_color', array(
  		'label' => __('Button Hover Background Color','dinero'),
	   'section' => 'dinero_about_section',
  	)));

  	$wp_customize->add_setting('dinero_about_onload_effects',array(
		'default' => 'fadeInUp',
		'sanitize_callback' => 'dinero_sanitize_choices',
	));
	$wp_customize->add_control('dinero_about_onload_effects',array(
		'type' => 'select',
		'label' => __('Onload Transition Effects','dinero'),
		'choices' => array (
			'zoomInUp' => __('Zoom In Up','dinero'),
			'fadeInUp' => __('Fade In Up','dinero'),
			'slideInLeft' => __('Slide In Left','dinero'),
			'slideInRight' => __('Slide In Right','dinero'),
			'slideInUp' => __('Slide In Up','dinero')
		),
		'section' => 'dinero_about_section',
	));

	//home page teams
	$wp_customize->add_section( 'dinero_teams_section' , array(
    	'title'    => __( 'Teams Section', 'dinero' ),
		'priority' => null,
		'panel' => 'dinero_panel_id2'
	) );

	$wp_customize->add_setting('dinero_reset_teams_settings',array(
      'sanitize_callback'	=> 'sanitize_text_field'
   ));
   $wp_customize->add_control(new Dinero_Reset_Custom_Control($wp_customize, 'dinero_reset_teams_settings',array(
      'type' => 'reset_control',
	   'priority' => 1,
      'label' => __('Reset Team Section Settings', 'dinero'),
      'description' => 'dinero_teams_reset_settings',
      'section' => 'dinero_teams_section'
   )));

	$wp_customize->add_setting('dinero_teams_section_option',array(
     'default' => 'Luzuk Teams Plugin',
     'sanitize_callback' => 'dinero_sanitize_choices'
	));
	$wp_customize->add_control('dinero_teams_section_option',array(
      'type' => 'select',
      'label' => __('Teams using','dinero'),
      'section' => 'dinero_teams_section',
      'choices' => array(
         'Luzuk Teams Plugin' => __('Luzuk Teams Plugin','dinero'),
         'Other Shortcode' => __('Other Shortcode','dinero')
      ),
	));

	$wp_customize->add_setting('dinero_teams_shortcode',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('dinero_teams_shortcode',array(
   	'type' => 'text',
   	'label' => __('Add Teams Section Shortcode','dinero'),
   	'section' => 'dinero_teams_section',
   	'active_callback' => 'dinero_teams_shortcode_enabled'
	));

	$wp_customize->add_setting('dinero_teams_section_small_title',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('dinero_teams_section_small_title',array(
   	'type' => 'text',
   	'label' => __('Add Section Small Title','dinero'),
   	'section' => 'dinero_teams_section',
	));

	$wp_customize->add_setting('dinero_teams_section_title',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('dinero_teams_section_title',array(
   	'type' => 'text',
   	'label' => __('Add Section Title','dinero'),
   	'section' => 'dinero_teams_section'
	));

	$wp_customize->add_setting('dinero_teams_section_width',array(
		'default' => 'Box Width',
		'sanitize_callback' => 'dinero_sanitize_choices',
	));
	$wp_customize->add_control('dinero_teams_section_width',array(
		'type' => 'select',
		'label' => __('Section Width','dinero'),
		'choices' => array (
			'Box Width' => __('Box Width','dinero'),
			'Full Width' => __('Full Width','dinero')
		),
		'section' => 'dinero_teams_section',
	));

	$wp_customize->add_setting( 'dinero_teams_small_title_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_teams_small_title_color', array(
  		'label' => __('Section Small Title Color','dinero'),
	   'section' => 'dinero_teams_section',
  	)));

	$wp_customize->add_setting( 'dinero_teams_section_title_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_teams_section_title_color', array(
  		'label' => __('Section Title Color','dinero'),
	   'section' => 'dinero_teams_section',
  	)));

	$wp_customize->add_setting( 'dinero_teams_section_bg_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_teams_section_bg_color', array(
  		'label' => __('Background Color','dinero'),
	   'section' => 'dinero_teams_section',
  	)));

	$wp_customize->add_setting( 'dinero_teams_section_bg_image', array(
	   'default' => '',
	   'sanitize_callback' => 'esc_url_raw'
  	));
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'dinero_teams_section_bg_image', array(
  		'label' => __('Background Image','dinero'),
	   'section' => 'dinero_teams_section',
  	)));

	$wp_customize->add_setting('dinero_teams_section_bg_opacity',array(
    	'default' => 1,
		'sanitize_callback' => 'dinero_sanitize_float'
	));
	$wp_customize->add_control(new Dinero_Custom_Control( $wp_customize, 'dinero_teams_section_bg_opacity',array(
   	'label' => __('Background Opacity','dinero'),
   	'section' => 'dinero_teams_section',
   	'input_attrs' => array(
			'min' => 0,
			'max' => 1,
			'step' => 0.1,
		),
	)));

	//Footer
    $wp_customize->add_section( 'dinero_footer', array(
    	'title'  => __( 'Footer', 'dinero' ),
		'priority' => null,
		'panel' => 'dinero_panel_id1'
	) );

	$wp_customize->add_setting('dinero_reset_footer_section',array(
      'sanitize_callback'	=> 'sanitize_text_field'
   ));
   $wp_customize->add_control(new Dinero_Reset_Custom_Control($wp_customize, 'dinero_reset_footer_section',array(
      'type' => 'reset_control',
	   'priority' => 1,
      'label' => __('Reset Footer Settings', 'dinero'),
      'description' => 'dinero_footer_reset_settings',
      'section' => 'dinero_footer'
   )));

	$wp_customize->add_setting('dinero_footer_section_tabs', array(
	   'sanitize_callback' => 'wp_kses_post',
	));
	$wp_customize->add_control(new Dinero_Tab_Control($wp_customize, 'dinero_footer_section_tabs', array(
	   'section' => 'dinero_footer',
	   'priority' => 1,
	   'buttons' => array(
	      array(
	         'name' => esc_html__('General', 'dinero'),
            'fields' => array(
            	'dinero_footer_copyright',
            	'dinero_footer_section_padding',
            	'dinero_footer_top_padding',
            	'dinero_footer_bottom_padding',
            	'dinero_footer_facebook_url',
            	'dinero_footer_twitter_url',
            	'dinero_footer_instagram_url',
            	'dinero_footer_linkedin_url'
            ),
            'active' => true,
         ),
	      array(
            'name' => esc_html__('Style', 'dinero'),
            'fields' => array(
            	'dinero_footer_section_bg_color1',
            	'dinero_footer_section_bg_color2',
            	'dinero_footer_section_bg_image',
            	'dinero_footer_section_bg_opacity',
            	'dinero_widget_title_color',
            	'dinero_widget_text_color',
            	'dinero_widget_list_color',
            	'dinero_widget_anchor_color',
            	'dinero_widget_anchor_hover_color',
            	'dinero_copyright_color',
            	'dinero_footer_social_icon_color',
            	'dinero_footer_social_icon_hover_color'
            ),
         )
    	),
	)));

	$wp_customize->add_setting('dinero_footer_section_padding',array(
      'sanitize_callback'	=> 'esc_html'
   ));
   $wp_customize->add_control('dinero_footer_section_padding',array(
      'label' => __('Section Padding','dinero'),
      'section' => 'dinero_footer'
   ));

	$wp_customize->add_setting('dinero_footer_top_padding',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_footer_top_padding',array(
      'type' => 'number',
      'description' => __('Top','dinero'),
      'section' => 'dinero_footer',
   ));

	$wp_customize->add_setting('dinero_footer_bottom_padding',array(
      'default' => '',
      'sanitize_callback'	=> 'dinero_sanitize_float'
   ));
   $wp_customize->add_control('dinero_footer_bottom_padding',array(
      'type' => 'number',
      'description' => __('Bottom','dinero'),
      'section' => 'dinero_footer',
   ));

 	$wp_customize->add_setting('dinero_footer_copyright',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('dinero_footer_copyright',array(
		'label'	=> __('Copyright Text','dinero'),
		'section' => 'dinero_footer',
		'setting' => 'dinero_footer_copyright',
		'type' => 'text'
	));

	$wp_customize->add_setting('dinero_footer_facebook_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('dinero_footer_facebook_url',array(
   	'type' => 'url',
   	'label' => __('Add Facebook URL','dinero'),
   	'section' => 'dinero_footer',
	));

	$wp_customize->add_setting('dinero_footer_twitter_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('dinero_footer_twitter_url',array(
   	'type' => 'url',
   	'label' => __('Add Twitter URL','dinero'),
   	'section' => 'dinero_footer',
	));

	$wp_customize->add_setting('dinero_footer_instagram_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('dinero_footer_instagram_url',array(
   	'type' => 'url',
   	'label' => __('Add Instagram URL','dinero'),
   	'section' => 'dinero_footer',
	));

	$wp_customize->add_setting('dinero_footer_linkedin_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('dinero_footer_linkedin_url',array(
   	'type' => 'url',
   	'label' => __('Add Linkedin URL','dinero'),
   	'section' => 'dinero_footer',
	));

	$wp_customize->add_setting( 'dinero_footer_section_bg_color1', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_footer_section_bg_color1', array(
  		'label' => __('Section Background Color 1','dinero'),
	   'section' => 'dinero_footer',
  	)));

	$wp_customize->add_setting( 'dinero_footer_section_bg_color2', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_footer_section_bg_color2', array(
  		'label' => __('Section Background Color 2','dinero'),
	   'section' => 'dinero_footer',
  	)));

	$wp_customize->add_setting( 'dinero_footer_section_bg_image', array(
	   'default' => '',
	   'sanitize_callback' => 'esc_url_raw'
  	));
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'dinero_footer_section_bg_image', array(
  		'label' => __('Section Background Image','dinero'),
	   'section' => 'dinero_footer',
  	)));

	$wp_customize->add_setting('dinero_footer_section_bg_opacity',array(
    	'default' => 0.9,
		'sanitize_callback' => 'dinero_sanitize_float'
	));
	$wp_customize->add_control(new Dinero_Custom_Control( $wp_customize, 'dinero_footer_section_bg_opacity',array(
   	'label' => __('Background Opacity','dinero'),
   	'section' => 'dinero_footer',
   	'input_attrs' => array(
			'min' => 0,
			'max' => 1,
			'step' => 0.1,
		),
	)));

	$wp_customize->add_setting( 'dinero_widget_title_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_widget_title_color', array(
  		'label' => __('Widget Title Color','dinero'),
	   'section' => 'dinero_footer',
  	)));

	$wp_customize->add_setting( 'dinero_widget_text_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_widget_text_color', array(
  		'label' => __('Widget Text Color','dinero'),
	   'section' => 'dinero_footer',
  	)));

	$wp_customize->add_setting( 'dinero_widget_list_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_widget_list_color', array(
  		'label' => __('Widget List Color','dinero'),
	   'section' => 'dinero_footer',
  	)));

	$wp_customize->add_setting( 'dinero_widget_anchor_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_widget_anchor_color', array(
  		'label' => __('Widget Anchor tag Color','dinero'),
	   'section' => 'dinero_footer',
  	)));

	$wp_customize->add_setting( 'dinero_widget_anchor_hover_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_widget_anchor_hover_color', array(
  		'label' => __('Widget Anchor tag hover Color','dinero'),
	   'section' => 'dinero_footer',
  	)));

	$wp_customize->add_setting( 'dinero_copyright_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_copyright_color', array(
  		'label' => __('Copyright Color','dinero'),
	   'section' => 'dinero_footer',
  	)));

	$wp_customize->add_setting( 'dinero_footer_social_icon_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_footer_social_icon_color', array(
  		'label' => __('Social Icons Color','dinero'),
	   'section' => 'dinero_footer',
  	)));

	$wp_customize->add_setting( 'dinero_footer_social_icon_hover_color', array(
	   'default' => '',
	   'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'dinero_footer_social_icon_hover_color', array(
  		'label' => __('Social Icons Hover Color','dinero'),
	   'section' => 'dinero_footer',
  	)));

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'dinero_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'dinero_customize_partial_blogdescription',
	) );

	//front page
	$num_sections = apply_filters( 'dinero_front_page_sections', 4 );

	// Create a setting and control for each of the sections available in the theme.
	for ( $i = 1; $i < ( 1 + $num_sections ); $i++ ) {
		$wp_customize->add_setting( 'panel_' . $i, array(
			'default'           => false,
			'sanitize_callback' => 'dinero_sanitize_dropdown_pages',
			'transport'         => 'postMessage',
		) );

		$wp_customize->add_control( 'panel_' . $i, array(
			/* translators: %d is the front page section number */
			'label'          => sprintf( __( 'Front Page Section %d Content', 'dinero' ), $i ),
			'description'    => ( 1 !== $i ? '' : __( 'Select pages to service in each area from the dropdowns. Add an image to a section by setting a serviced image in the page editor. Empty sections will not be displayed.', 'dinero' ) ),
			'section'        => 'theme_options',
			'type'           => 'dropdown-pages',
			'allow_addition' => true,
			'active_callback' => 'dinero_is_static_front_page',
		) );

		$wp_customize->selective_refresh->add_partial( 'panel_' . $i, array(
			'selector'            => '#panel' . $i,
			'render_callback'     => 'dinero_front_page_section',
			'container_inclusive' => true,
		) );
	}

   $wp_customize->register_control_type('Dinero_Tab_Control');
	$wp_customize->register_panel_type( 'Dinero_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'Dinero_WP_Customize_Section' );
}
add_action( 'customize_register', 'dinero_customize_register' );

function dinero_customize_partial_blogname() {
	bloginfo( 'name' );
}

function dinero_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

function dinero_is_static_front_page() {
	return ( is_front_page() && ! is_home() );
}

function dinero_is_view_with_layout_option() {
	// This option is available on all pages. It's also available on archives when there isn't a sidebar.
	return ( is_page() || ( is_archive() && ! is_active_sidebar( 'sidebar-1' ) ) );
}

if (class_exists('WP_Customize_Control')) {

	class Dinero_Fontawesome_Icon_Chooser extends WP_Customize_Control {

	   public $type = 'icon';

	   public function render_content() {
	      ?>
	      <label>
	         <span class="customize-control-title">
	            <?php echo esc_html($this->label); ?>
	         </span>

	         <?php if ($this->description) { ?>
	            <span class="description customize-control-description">
	               <?php echo wp_kses_post($this->description); ?>
	            </span>
	         <?php } ?>

	         <div class="dinero-selected-icon">
	            <i class="fa <?php echo esc_attr($this->value()); ?>"></i>
	              <span><i class="fa fa-angle-down"></i></span>
	         </div>

	         <ul class="dinero-icon-list clearfix">
	            <?php
	            $dinero_font_awesome_icon_array = dinero_font_awesome_icon_array();
	            foreach ($dinero_font_awesome_icon_array as $dinero_font_awesome_icon) {
	               $icon_class = $this->value() == $dinero_font_awesome_icon ? 'icon-active' : '';
	               echo '<li class=' . esc_attr($icon_class) . '><i class="' . esc_attr($dinero_font_awesome_icon) . '"></i></li>';
	            }
	            ?>
	         </ul>
	         <input type="hidden" value="<?php $this->value(); ?>" <?php $this->link(); ?> />
	      </label>
	      <?php
	   }
	}
}

function dinero_customizer_script() {
   wp_enqueue_style( 'font-awesome-1', esc_url(get_template_directory_uri()).'/assets/css/fontawesome-all.css');
}
add_action( 'customize_controls_enqueue_scripts', 'dinero_customizer_script' );

if ( class_exists( 'WP_Customize_Panel' ) ) {
  	class Dinero_WP_Customize_Panel extends WP_Customize_Panel {
	   public $panel;
	   public $type = 'dinero_panel';
	   public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;
	      return $array;
    	}
  	}
}

if ( class_exists( 'WP_Customize_Section' ) ) {
  	class Dinero_WP_Customize_Section extends WP_Customize_Section {
	   public $section;
	   public $type = 'dinero_section';
	   public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;

	      if ( $this->panel ) {
	        $array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );
	      } else {
	        $array['customizeAction'] = 'Customizing';
	      }
	      return $array;
    	}
  	}
}